==> dxcr-vue-cesium-0.0.1.tgz: package/lib/extend/doubleRoatatingCircle/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _Object$defineProperties from '@babel/runtime-corejs2/core-js/object/define-properties';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import _Promise from '@babel/runtime-corejs2/core-js/promise';
import cmp from '../../mixins/virtualCmp';
import { position, show } from '../../mixins/mixinProps';

var script = {
  name: 'vc-circle-roatating-double',
  mixins: [cmp, position, show],
  props: {
    height: {
      type: Number,
      default: undefined
    },
    radius1: {
      type: Number,
      default: 1500
    },
    radius2: {
      type: Number,
      default: 3000
    },
    material1: Object | String | Array,
    material2: Object | String | Array,
    deviationRotation1: {
      type: Number,
      default: -0.03
    },
    deviationRotation2: {
      type: Number,
      default: 0.05
    }
  },
  data: function data() {
    return {
      r1: 0,
      r2: 0,
      rotation1: 0,
      stRotation1: 0,
      rotation2: 0,
      stRotation2: 0,
      nowaiting: true
    };
  },
  mounted: function mounted() {
    var _this = this;

    this.getParent(this.$parent).createPromise.then(function (_ref) {
      var Cesium = _ref.Cesium,
          viewer = _ref.viewer;

      _this.init();
    });
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this2 = this;

      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              return _context.abrupt("return", _Promise.all([this.$refs.entity1.createPromise, this.$refs.entity2.createPromise]).then(function (entities) {
                if (!_this2.$refs.entity1._mounted || !_this2.$refs.entity1._mounted) {
                  return _Promise.all([_this2.$refs.entity1.load(), _this2.$refs.entity2.load()]).then(function (entities) {
                    _this2.init();

                    return entities;
                  });
                } else {
                  return entities;
                }
              }));

            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    },
    init: function init() {
      var deviationRotation1 = this.deviationRotation1,
          deviationRotation2 = this.deviationRotation2,
          radius1 = this.radius1,
          radius2 = this.radius2;
      var scratchR1 = 0.01;
      var scratchR2 = 0.01;
      var startFlag = false;
      setTimeout(function () {
        startFlag = true;
      });
      this.r1 = new Cesium.CallbackProperty(function () {
        if (startFlag) {
          scratchR1 += radius1 / 20;

          if (scratchR1 >= radius1) {
            scratchR1 = radius1;
          }
        }

        return scratchR1;
      }, false);
      this.r2 = new Cesium.CallbackProperty(function () {
        if (startFlag) {
          scratchR2 += radius2 / 20;

          if (scratchR2 >= radius2) {
            scratchR2 = radius2;
          }
        }

        return scratchR2;
      }, false);
      var startrotation1 = Cesium.Math.toRadians(30);
      this.rotation1 = new Cesium.CallbackProperty(function () {
        startrotation1 += deviationRotation1;
        return startrotation1;
      }, false);
      this.stRotation1 = new Cesium.CallbackProperty(function () {
        startrotation1 += deviationRotation1;
        return startrotation1;
      }, false);
      var startrotation2 = Cesium.Math.toRadians(30);
      this.rotation2 = new Cesium.CallbackProperty(function () {
        startrotation2 += deviationRotation2;
        return startrotation2;
      }, false);
      this.stRotation2 = new Cesium.CallbackProperty(function () {
        startrotation2 += deviationRotation2;
        return startrotation2;
      }, false);
    },
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", true);

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              this.r1 = undefined;
              this.r2 = undefined;
              this.rotation1 = undefined;
              this.rotation2 = undefined;
              this.stRotation1 = undefined;
              this.stRotation2 = undefined;
              return _context3.abrupt("return", this.$refs.entity1 && this.$refs.entity2 ? _Promise.all([this.$refs.entity1.unload(), this.$refs.entity2.unload()]) : true);

            case 7:
            case "end":
              return _context3.stop();
          }
        }
      }, null, this);
    }
  },
  created: function created() {
    var _this3 = this;

    _Object$defineProperties(this, {
      entities: {
        enumerable: true,
        get: function get() {
          return _this3.cesiumObject;
        }
      }
    });
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-entity', {
    ref: "entity1",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material1,
      "rotation": _vm.rotation1,
      "semiMajorAxis": _vm.r1,
      "semiMinorAxis": _vm.r1,
      "stRotation": _vm.stRotation1
    }
  })], 1), _vm._v(" "), _c('vc-entity', {
    ref: "entity2",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material2,
      "rotation": _vm.rotation2,
      "semiMajorAxis": _vm.r2,
      "semiMinorAxis": _vm.r2,
      "stRotation": _vm.stRotation2
    }
  })], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcDoubleRotatingCircle.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcDoubleRotatingCircle = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(VcDoubleRotatingCircle.name, VcDoubleRotatingCircle);
}

export default plugin;
export { VcDoubleRotatingCircle, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/extend/doubleRoatatingCircle/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _Object$defineProperties from '@babel/runtime-corejs2/core-js/object/define-properties';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import _Promise from '@babel/runtime-corejs2/core-js/promise';
import cmp from '../../mixins/virtualCmp';
import { position, show, height } from '../../mixins/mixinProps';
import * as Entity from '../../entity';
import * as EllipseGraphics from '../../entity/ellipse';

var script = {
  name: 'vc-circle-roatating-double',
  mixins: [cmp, position, show, height],
  props: {
    radius1: {
      type: Number,
      default: 1500
    },
    radius2: {
      type: Number,
      default: 3000
    },
    material1: [Object, String, Array],
    material2: [Object, String, Array],
    deviationRotation1: {
      type: Number,
      default: -0.03
    },
    deviationRotation2: {
      type: Number,
      default: 0.05
    }
  },
  data: function data() {
    return {
      rotation1: 0,
      stRotation1: 0,
      rotation2: 0,
      stRotation2: 0,
      nowaiting: true
    };
  },
  mounted: function mounted() {
    var _this = this;

    this.getParent(this.$parent).createPromise.then(function (_ref) {
      var Cesium = _ref.Cesium,
          viewer = _ref.viewer;

      _this.init();
    });
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this2 = this;

      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              return _context.abrupt("return", _Promise.all([this.$refs.entity1.createPromise, this.$refs.entity2.createPromise]).then(function (entities) {
                if (!_this2.$refs.entity1._mounted || !_this2.$refs.entity1._mounted) {
                  return _Promise.all([_this2.$refs.entity1.load(), _this2.$refs.entity2.load()]).then(function (entities) {
                    _this2.init();

                    return entities;
                  });
                } else {
                  return entities;
                }
              }));

            case 1:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    },
    init: function init() {
      var deviationRotation1 = this.deviationRotation1,
          deviationRotation2 = this.deviationRotation2;
      var startrotation1 = Cesium.Math.toRadians(30);

      var getRotationValue1 = function getRotationValue1() {
        startrotation1 += deviationRotation1;
        return startrotation1;
      };

      this.rotation1 = getRotationValue1;
      this.stRotation1 = getRotationValue1;
      var startrotation2 = Cesium.Math.toRadians(30);

      var getRotationValue2 = function getRotationValue2() {
        startrotation2 += deviationRotation2;
        return startrotation2;
      };

      this.rotation2 = getRotationValue2;
      this.stRotation2 = getRotationValue2;
    },
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", true);

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              this.rotation1 = undefined;
              this.rotation2 = undefined;
              this.stRotation1 = undefined;
              this.stRotation2 = undefined;
              return _context3.abrupt("return", this.$refs.entity1 && this.$refs.entity2 ? _Promise.all([this.$refs.entity1.unload(), this.$refs.entity2.unload()]) : true);

            case 5:
            case "end":
              return _context3.stop();
          }
        }
      }, null, this);
    }
  },
  created: function created() {
    var _this3 = this;

    _Object$defineProperties(this, {
      entities: {
        enumerable: true,
        get: function get() {
          return _this3.cesiumObject;
        }
      }
    });
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-entity', {
    ref: "entity1",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material1,
      "rotation": _vm.rotation1,
      "semiMajorAxis": _vm.radius1,
      "semiMinorAxis": _vm.radius1,
      "stRotation": _vm.stRotation1
    }
  })], 1), _vm._v(" "), _c('vc-entity', {
    ref: "entity2",
    attrs: {
      "position": _vm.position,
      "show": _vm.show
    }
  }, [_c('vc-graphics-ellipse', {
    attrs: {
      "height": _vm.height,
      "material": _vm.material2,
      "rotation": _vm.rotation2,
      "semiMajorAxis": _vm.radius2,
      "semiMinorAxis": _vm.radius2,
      "stRotation": _vm.stRotation2
    }
  })], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcDoubleRotatingCircle.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcDoubleRotatingCircle = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.use(Entity);
  Vue.use(EllipseGraphics);
  Vue.component(VcDoubleRotatingCircle.name, VcDoubleRotatingCircle);
}

export default plugin;
export { VcDoubleRotatingCircle, plugin as install };
